aadb2c_js: Generate some initial JS code to authenticate against AAD B2C

Description Usage Arguments Value Examples

View source: R/aadb2c_js.R

Description

Generate some initial JS code to authenticate against AAD B2C

Usage

1
2
3
4
5
6
7
8
aadb2c_js(
  output_dir = ".",
  shiny_input = "email",
  tenant = "shortname",
  client_id = "guid",
  signin_policy = "B2C_1_signup_signin",
  scopes = c("email", "openid", "https://someresource/read")
)

Arguments

output_dir

Where the JS file should be output

shiny_input

The id of the input that should be given the user's email

tenant

The AAD B2C tenant name (no onmicrosoft.com bit)

client_id

The application ID of the AAD B2C app

signin_policy

The User Flow / Policy to use to Sign In

scopes

The scopes that should be requested, including a URI. Typically the URI is a variant of the App API URI

Value

Configured JS file's location

Examples

1

lockedata/shiny.AADB2C documentation built on Dec. 5, 2019, 12:49 a.m.