Description Usage Arguments Value Examples
Generate some initial JS code to authenticate against AAD B2C
1 2 3 4 5 6 7 8 |
output_dir |
Where the JS file should be output |
shiny_input |
The id of the input that should be given the user's email |
tenant |
The AAD B2C tenant name (no onmicrosoft.com bit) |
client_id |
The application ID of the AAD B2C app |
signin_policy |
The User Flow / Policy to use to Sign In |
scopes |
The scopes that should be requested, including a URI. Typically the URI is a variant of the App API URI |
Configured JS file's location
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.